squizz and biopython returns different header and may be lower or upper cases; 
So, instead of storing the different outputs, we just store the input genbank and
we will use hard-coded md5 in the test file.

